Error

Enum Error 

pub enum Error {
    Validation(String),
    OutOfMemory(String),
    Internal(String),
}
Variants



Validation(String)



OutOfMemory(String)



Internal(String)

Implementations

Source

impl Error

pub fn filter(&self) -> ErrorFilter

pub fn message(&self) -> &str

pub fn from_wgpu_error<E: WebGpuError>(error: E) -> Option<Self>

Converts a wgpu’s errors into a (GPU)Error if possible. Returns None if device is lost, as those need to be ignored in validation as they are handled by device lost callback